ResetTime

Enum ResetTime 

pub enum ResetTime {
    Seconds(usize),
    DateTime(OffsetDateTime),
}
Reset time of rate limiting

There are different variants on how to specify reset times in rate limit headers. The most common ones are seconds and datetime.

Variants



Seconds(usize)

Number of seconds until rate limit is lifted



DateTime(OffsetDateTime)

Date when rate limit will be lifted

Implementations

Source

impl ResetTime

pub fn seconds(&self) -> usize

Get the number of seconds until the rate limit gets lifted.

pub fn duration(&self) -> Duration

Convert reset time to duration