Vendor

Enum Vendor 

pub enum Vendor {
    Generic,
    Akamai,
    Discord,
    Github,
    Gitlab,
    Linear,
    OpenAI,
    PolliDraft,
    Reddit,
    Twilio,
    Twitter,
    Vimeo,
}
Known vendors of rate limit headers

Vendors use different rate limit header formats, which define how to parse them.

Variants



Generic

Generic vendor, but valid rate limit headers.

APIs like Notion, Figma, Supabase, and Twitch rely on standard headers and are officially and fully supported via this generic fallback.



Akamai



Discord



Github



Gitlab



Linear

Linear rate limit headers (GraphQL).

https://linear.app/developers/rate-limiting



OpenAI



PolliDraft

Rate limit headers as defined in the polli-ratelimit-headers-00 IETF draft.

https://datatracker.ietf.org/doc/html/draft-polli-ratelimit-headers-00



Reddit



Twilio



Twitter

Twitter / X API rate limit headers.

https://docs.x.com/x-api/fundamentals/rate-limits



Vimeo