Headers

Struct Headers 

pub struct Headers {
    pub limit: usize,
    pub remaining: usize,
    pub reset: ResetTime,
    pub window: Option<Duration>,
    pub vendor: Vendor,
}
HTTP rate limits as parsed from header values

Fields

limit: usize

The maximum number of requests allowed in the time window

remaining: usize

The number of requests remaining in the time window

reset: ResetTime

The time at which the rate limit will be reset

window: Option<Duration>

The time window until the rate limit is lifted. It is optional, because it might not be given, in which case it needs to be inferred from the environment

vendor: Vendor

Predicted vendor based on rate limit header

Implementations

Source

impl Headers

pub fn new<T: Into<CaseSensitiveHeaderMap>>(headers: T) -> Result<Self, Error>

Extracts rate limits from HTTP headers.

Different vendors (e.g. GitHub, Vimeo, Twitter) use different header names. This function attempts to identify the vendor based on the presence of known headers.

There are many websites abusing or reusing rate limit headers with their own definition of what the values mean. This library tries to be pessimistic and only attempts to parse the rate limit headers if it trusts the website to follow one of the supported variants.

Some vendors might use the same header names but different value formats. In this case, the library will try to parse the headers using the different variants until one succeeds.

Errors

Returns an error if the headers do not contain a known rate limit format, or if the header values cannot be parsed.

pub const fn limit(&self) -> usize

Get the number of requests allowed in the time window

pub const fn remaining(&self) -> usize

Get the number of requests remaining in the time window

pub const fn reset(&self) -> ResetTime

Get the time at which the rate limit will be reset