RateLimit

Enum RateLimit 

pub enum RateLimit {
    Rfc6585(Headers),
    RetryAfter(RateLimit),
}
Rate Limit information, parsed from HTTP headers.

There are multiple ways to represent rate limit information in HTTP headers. The following variants are supported:

Variants



Rfc6585(Headers)

Rate limit information as per the [IETF “Polly” draft][ietf].



RetryAfter(RateLimit)

Rate limit information as per the [Retry-After][retryafter] header.

Implementations

Source

impl RateLimit

pub fn new(headers: &HeaderMap) -> Result<Self, Error>

Create a new RateLimit from a http::HeaderMap.

pub fn extract<'a, I>(headers: I) -> Result<Self, Error>
where I: IntoIterator<Item = (&'a str, &'a str)> + Clone,

Create a new RateLimit from an iterator over HTTP headers.

pub const fn is_limited(&self) -> bool

Check if the rate limit has been reached.

pub fn status(&self) -> Status

Get the current status of the rate limit.

pub const fn reset(&self) -> ResetTime

Get reset time. This is the time when the rate limit will be reset.

pub const fn limit(&self) -> Option<usize>

Get limit value.

This is the maximum number of requests that can be made in a given time window.

pub const fn remaining(&self) -> Option<usize>

Get remaining value.

This is the number of requests remaining in the current time window.