pub struct VendorMask(/* private fields */);Expand description
A lightweight bitmask for tracking sets of candidate vendors without allocation.
Each identifiable vendor occupies a single bit. Combine them using the usual bitwise operators:
use rate_limits::VendorMask;
let mask = VendorMask::GITHUB | VendorMask::AKAMAI;
assert_eq!(mask.count(), 2);
assert!(mask.contains(VendorMask::GITHUB));Vendor::Generic is intentionally not representable, since it
denotes the absence of a specific vendor match. Converting it via
VendorMask::from yields an empty mask.
Implementations
Sourceimpl VendorMask
impl VendorMask
Sourcepub const AKAMAI: Self
pub const AKAMAI: Self
See Vendor::Akamai.
Sourcepub const DISCORD: Self
pub const DISCORD: Self
See Vendor::Discord.
Sourcepub const GITHUB: Self
pub const GITHUB: Self
See Vendor::Github.
Sourcepub const GITLAB: Self
pub const GITLAB: Self
See Vendor::Gitlab.
Sourcepub const LINEAR: Self
pub const LINEAR: Self
See Vendor::Linear.
Sourcepub const OPENAI: Self
pub const OPENAI: Self
See Vendor::OpenAI.
Sourcepub const POLLI_DRAFT: Self
pub const POLLI_DRAFT: Self
See Vendor::PolliDraft.
Sourcepub const REDDIT: Self
pub const REDDIT: Self
See Vendor::Reddit.
Sourcepub const TWILIO: Self
pub const TWILIO: Self
See Vendor::Twilio.
Sourcepub const TWITTER: Self
pub const TWITTER: Self
See Vendor::Twitter.
Sourcepub const VIMEO: Self
pub const VIMEO: Self
See Vendor::Vimeo.
Sourceimpl VendorMask
impl VendorMask
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl VendorMask
impl VendorMask
Sourcepub const fn iter(&self) -> Iter<VendorMask>
pub const fn iter(&self) -> Iter<VendorMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<VendorMask>
pub const fn iter_names(&self) -> IterNames<VendorMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl VendorMask
impl VendorMask
Sourcepub fn single(self) -> Option<Vendor>
pub fn single(self) -> Option<Vendor>
Returns the single Vendor if exactly one bit is set, otherwise None.
Sourcepub const fn vendors(self) -> VendorMaskIter
pub const fn vendors(self) -> VendorMaskIter
Returns an iterator over the Vendors present in this mask.
Note: this is distinct from the bit-level IntoIterator impl
provided by bitflags, which yields one-bit VendorMask values.